#
# spec file for package cunit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%define _lto_cflags %{nil}
%define _name   CUnit
%define _version 2.1-3
%define _libname libcunit1
Name:           cunit
Version:        2.1.3
Release:        7.5
Summary:        It provides C programmers a basic testing functionality
License:        LGPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            https://cunit.sourceforge.net/
Source0:        https://download.sourceforge.net/cunit/%{_name}-%{_version}.tar.bz2
Patch0:         cunit-link-ncurses.diff
Patch1:         cunit-ncurses6.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig

%description
CUnit is a unit testing framework for C.
This package installs the CUnit static library,
headers, and documentation files.

%package devel
Summary:        CUnit development files
Group:          Development/Libraries/C and C++
Requires:       %{_libname} = %{version}
Requires:       ncurses-devel
Requires:       pkgconfig
%if 0%{?suse_version} || 0%{?fedora_version}
Recommends:     %{name}-doc = %{version}
%endif

%description devel
CUnit is a unit testing framework for C.
This package installs the CUnit development files.

%package doc
Summary:        CUnit documentation
Group:          Documentation/Man
Requires:       %{_libname} = %{version}

%description doc
CUnit is a unit testing framework for C.
This package installs the CUnit
documentation files.

%package -n %{_libname}
Summary:        CUnit shared library
Group:          System/Libraries

%description  -n %{_libname}
CUnit is a unit testing framework for C.
This package installs the CUnit shared library.

%prep
%autosetup -p1 -n %{_name}-%{_version}

chmod -x AUTHORS ChangeLog COPYING NEWS README TODO doc/*.html doc/*.css

%build
autoreconf -fi
%configure \
    --disable-static \
    --enable-automated \
    --enable-basic \
    --enable-console \
    --enable-curses \
    --enable-examples \
    --enable-test
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_prefix}/doc
# arch dependent files
mkdir -p %{buildroot}%{_libdir}/CUnit/
mv %{buildroot}%{_datadir}/CUnit/Examples/ %{buildroot}%{_libdir}/CUnit/
mv %{buildroot}%{_datadir}/CUnit/Test/     %{buildroot}%{_libdir}/CUnit/
chmod -x doc/headers/*
rm doc/headers/Makefile*
rm doc/headers/Jamfile*
rm doc/Makefile*
rm doc/Jamfile*

%post -n %{_libname} -p /sbin/ldconfig
%postun -n %{_libname} -p /sbin/ldconfig

%files -n %{_libname}
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%{_libdir}/libcunit.so.*

%files doc
%doc doc/*
%dir %{_datadir}/CUnit
%{_datadir}/CUnit/*
%{_mandir}/man3/CUnit.3%{?ext_man}

%files devel
%dir %{_includedir}/CUnit
%{_includedir}/CUnit/*
%dir %{_libdir}/CUnit
%{_libdir}/CUnit/*
%{_libdir}/libcunit.so
%{_libdir}/pkgconfig/cunit.pc

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Feb  6 2024 Fridrich Strba <fstrba@suse.com>
- Disable LTO to avoid undefined symbols on some platforms
- Clean the spec file up a bit
* Thu Oct 22 2015 idonmez@suse.com
- Add cunit-ncurses6.patch to compile with ncurses6
* Tue May 26 2015 ddiss@suse.com
- Don't tag Recommends on RHEL, it yields an "Unknown tag" error.
* Tue Aug 12 2014 tchvatal@suse.com
- Use proper group for the library.
* Mon Aug  4 2014 tchvatal@suse.com
- The license is actually LGPL
* Mon Aug  4 2014 tchvatal@suse.com
- Update to release 2.1.3:
  * prune the static-devel subpackage as it is pointless.
  * Various upstream fixes with no changelog.
- Cleanup with spec-cleaner to have the spec pretty
* Thu Feb  9 2012 jengelh@medozas.de
- Update to new upstream release 2.1.2
  * modified dtd and xsl files to support inactive suites/tests
  * Added ability to deactivate suite/tests dynamically
  * Removed constraint that suite/test names be unique
- Remove redundant tags/sections
- Parallel build with %%_smp_mflags
- Add autotools BuildRequires for factory/12.2
- Fix use of implicitly defined function in source
  (do not declare that post-build-checks's output was wrong)
- Add missing DT_NEEDED entry on ncurses
* Tue Jun  8 2010 andrea@opensuse.org
- fixed 'no-pkg-config-provides'
* Wed Apr 21 2010 prusnak@suse.cz
- cleaned up spec, split devel-static subpackage
* Sat Mar 13 2010 andrea@opensuse.org
- added CUnit-2.1-pkgconfig.patch to provide cunit.pc
* Wed Mar  3 2010 andrea@opensuse.org
- split into 3 subpackages
* Tue Mar  2 2010 andrea@opensuse.org
- New package
